
=============
 elf Package
=============

Parse Executable-Linking Files (Unix ELF binary files). See https://en.wikipedia.org/wiki/Executable_and_Linkable_Format for general reference.

Script Usage

    elf.py <input ELF filename>

==========
 Features
==========

* 32- and 64-bit ELF parsing
* ELF class for convenient abstraction
* ElfBytes class for byte-level operations
* Summary inspection
* Dynamic linking dependency lookup

